
/**
 * Show info about how many lines have been removed
 *
 * @param  integer     removeCount: the number of removed lines
 *
 * @return void
 */
function ShowRemoveCount(removeCount) {
	var msg = _t(removeCount) + " empty lines removed.";
	Script.Status = msg; // Useless as status message gets overwritten by internal data once plugin finishes
	if ((removeCount) && (Script.ReadSetting("Show info after action", "1")== "1")) {
		Alert(msg);
	}
}

/**
 * Remove ALL empty lines
 *
 * @return void
 */
function RemoveAllEmptyLines() {
	var userSelection = Editor.Selection,
			removeCount = 0;

	Editor.BeginEditing;

  for (var lineCount = Editor.LineCount - 1; lineCount > 0; lineCount--) {
		var currentLine = Trim(Editor.Lines[lineCount]);
		if ( Length(currentLine) == 0 ) {
    	userSelection.SelStartLine = lineCount;
			userSelection.SelStartCol = 0;
			userSelection.SelEndLine = lineCount + 1;
			userSelection.SelEndCol = 0;
			Editor.Selection = userSelection;
			Editor.SelText = currentLine;
			removeCount++;
		}
	}

	Editor.EndEditing;

	ShowRemoveCount(removeCount);
}

/**
 * Remove empty double lines
 *
 * @return void
 */
function RemoveEmptyDoubleLines() {
	var lastLine = "-",
			userSelection = Editor.Selection,
			removeCount = 0;

	Editor.BeginEditing;

  for (var lineCount = Editor.LineCount - 1; lineCount > 0; lineCount--) {
		var currentLine = Trim(Editor.Lines[lineCount]);
		if ( (currentLine == lastLine) && (Length(currentLine) == 0) ) {
    	userSelection.SelStartLine = lineCount;
			userSelection.SelStartCol = 0;
			userSelection.SelEndLine = lineCount + 1;
			userSelection.SelEndCol = 0;
			Editor.Selection = userSelection;
			Editor.SelText = currentLine;
			removeCount++;
		}
		lastLine = currentLine;
	}

	Editor.EndEditing;

	ShowRemoveCount(removeCount);
}

/**
 * Show info when plugin is installed
 *
 * @return void
 */
function OnInstalled() {
  Alert("Remove Empty Lines 1.1 by Peter Klein installed sucessfully!");
}

Script.ConnectSignal("installed", "OnInstalled");
Script.RegisterDocumentAction("Remove Empty Lines", "Remove All Empty Lines", "Ctrl+Shift+Z", "RemoveAllEmptyLines");
Script.RegisterDocumentAction("Remove Empty Lines", "Remove Empty Double Lines", "Ctrl+Shift+X", "RemoveEmptyDoubleLines");
